@@ -21,21 +21,24 @@
  * 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <utime.h>
 #include <errno.h>
 
-#include <libedataserver/e-sexp.h>
-#include <libedataserver/e-util.h>
-#include <libebook/e-contact.h>
-#include "e-book-backend-summary.h"
+#include <glib.h>
+#include <glib/gstdio.h>
 
+#include "libedataserver/e-sexp.h"
+#include "libedataserver/e-data-server-util.h"
+
+#include "libebook/e-contact.h"
+
+#include "e-book-backend-summary.h"
 
 static GObjectClass *parent_class;
 
@@ -132,8 +135,10 @@ clear_items (EBookBackendSummary *summary)
 	int num = summary->priv->items->len;
 	for (i = 0; i < num; i++) {
 		EBookBackendSummaryItem *item = g_ptr_array_remove_index_fast (summary->priv->items, 0);
-		g_hash_table_remove (summary->priv->id_to_item, item->id);
-		free_summary_item (item);
+		if (item) {
+			g_hash_table_remove (summary->priv->id_to_item, item->id);
+			free_summary_item (item);
+		}
 	}
 }
 
@@ -167,17 +172,18 @@ e_book_backend_summary_dispose (GObject *object)
 	EBookBackendSummary *summary = E_BOOK_BACKEND_SUMMARY (object);
 
 	if (summary->priv) {
+		if (summary->priv->fp)
+			fclose (summary->priv->fp);
 		if (summary->priv->dirty)
-			g_warning ("Destroying dirty summary");
+			e_book_backend_summary_save (summary);
+		else
+			utime (summary->priv->summary_path, NULL);
 
 		if (summary->priv->flush_timeout) {
 			g_source_remove (summary->priv->flush_timeout);
 			summary->priv->flush_timeout = 0;
 		}
 
-		if (summary->priv->fp)
-			fclose (summary->priv->fp);
-
 		g_free (summary->priv->summary_path);
 		clear_items (summary);
 		g_ptr_array_free (summary->priv->items, TRUE);
@@ -466,23 +472,22 @@ e_book_backend_summary_open (EBookBackendSummary *summary)
 	if (summary->priv->fp)
 		return TRUE;
 
-	if (stat (summary->priv->summary_path, &sb) == -1) {
+	if (g_stat (summary->priv->summary_path, &sb) == -1) {
 		/* if there's no summary present, look for the .new
 		   file and rename it if it's there, and attempt to
 		   load that */
 		char *new_filename = g_strconcat (summary->priv->summary_path, ".new", NULL);
-		if (stat (new_filename, &sb) == -1) {
-			g_warning ("no summary present");
+		if (g_stat (new_filename, &sb) == -1) {
 			g_free (new_filename);
 			return FALSE;
 		}
 		else {
-			rename (new_filename, summary->priv->summary_path);
+			g_rename (new_filename, summary->priv->summary_path);
 			g_free (new_filename);
 		}
 	}
 
-	fp = fopen (summary->priv->summary_path, "r");
+	fp = g_fopen (summary->priv->summary_path, "rb");
 	if (!fp) {
 		g_warning ("failed to open summary file");
 		return FALSE;
@@ -502,7 +507,7 @@ e_book_backend_summary_open (EBookBackendSummary *summary)
 
 	summary->priv->num_items = header.num_items;
 	summary->priv->file_version = header.file_version;
-	summary->priv->mtime = header.summary_mtime;
+	summary->priv->mtime = sb.st_mtime;
 	summary->priv->fp = fp;
 
 	return TRUE;
@@ -680,7 +685,7 @@ e_book_backend_summary_save (EBookBackendSummary *summary)
 
 	new_filename = g_strconcat (summary->priv->summary_path, ".new", NULL);
 
-	fp = fopen (new_filename, "w");
+	fp = g_fopen (new_filename, "wb");
 	if (!fp) {
 		g_warning ("could not create new summary file");
 		goto lose;
@@ -713,13 +718,13 @@ e_book_backend_summary_save (EBookBackendSummary *summary)
 	}
 
 	/* unlink the old summary and rename the new one */
-	unlink (summary->priv->summary_path);
-	rename (new_filename, summary->priv->summary_path);
+	g_unlink (summary->priv->summary_path);
+	g_rename (new_filename, summary->priv->summary_path);
 
 	g_free (new_filename);
 
 	/* lastly, update the in memory mtime to that of the file */
-	if (stat (summary->priv->summary_path, &sb) == -1) {
+	if (g_stat (summary->priv->summary_path, &sb) == -1) {
 		g_warning ("error stat'ing saved summary");
 	}
 	else {
@@ -733,7 +738,7 @@ e_book_backend_summary_save (EBookBackendSummary *summary)
 	if (fp)
 		fclose (fp);
 	if (new_filename)
-		unlink (new_filename);
+		g_unlink (new_filename);
 	g_free (new_filename);
 	return FALSE;
 }
@@ -853,9 +858,9 @@ summary_flush_func (gpointer data)
 		g_warning ("failed to flush summary file to disk");
 		return TRUE; /* try again after the next timeout */
 	}
-
-	g_warning ("flushed summary to disk");
-
+	
+	g_message ("Flushed summary to disk");
+	
 	/* we only want this to execute once, so return FALSE and set
 	   summary->flush_timeout to 0 */
 	summary->priv->flush_timeout = 0;
@@ -1056,7 +1061,7 @@ func_contains(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data
 static char *
 is_helper (const char *s1, const char *s2)
 {
-	if (!strcasecmp(s1, s2))
+	if (!e_util_utf8_strcasecmp(s1, s2))
 		return (char*)s1;
 	else
 		return NULL;
