@@ -31,6 +31,7 @@
 
 #include "libedataserver/e-memory.h"
 #include "libedataserver/e-msgport.h"
+#include "libedataserver/e-data-server-util.h"
 
 #include "camel-file-utils.h"
 #include "camel-object.h"
@@ -240,7 +241,8 @@ cobject_finalise(CamelObject *o)
 {
 	/*printf("%p: finalise %s\n", o, o->klass->name);*/
 
-	g_assert(o->ref_count == 0);
+	if (o->ref_count == 0)
+		return;
 
 	camel_object_free_hooks(o);
 
@@ -455,7 +457,7 @@ cobject_state_read(CamelObject *obj, FILE *fp)
 		}
 		
 		/* we batch up the properties and set them in one go */
-		if (!(argv = g_try_malloc (sizeof (*argv) + (count - CAMEL_ARGV_MAX) * sizeof (argv->argv[0]))))
+		if (!(argv = g_try_malloc ((gulong)(sizeof (*argv) + (count - CAMEL_ARGV_MAX) * sizeof (argv->argv[0])))))
 			return -1;
 		
 		argv->argc = 0;
@@ -1351,7 +1353,7 @@ camel_object_remove_event(void *vo, unsigned int id)
 	g_return_if_fail (id != 0);
 
 	if (obj->hooks == NULL) {
-		g_warning("camel_object_unhook_event: trying to unhook `%d` from an instance of `%s' with no hooks",
+		g_warning("camel_object_unhook_event: trying to unhook `%u` from an instance of `%s' with no hooks",
 			  id, obj->klass->name);
 		return;
 	}
@@ -1381,7 +1383,7 @@ camel_object_remove_event(void *vo, unsigned int id)
 	}
 	camel_object_unget_hooks(obj);
 
-	g_warning("camel_object_unhook_event: cannot find hook id %d in instance of `%s'",
+	g_warning("camel_object_unhook_event: cannot find hook id %u in instance of `%s'",
 		  id, obj->klass->name);
 }
 
@@ -1456,8 +1458,7 @@ camel_object_trigger_event(void *vo, const char * name, void *event_data)
 	pair = co_find_pair_ptr(obj->klass, interface_name);
 	if (pair) {
 		GPtrArray *interfaces = pair->data;
-		int i;
-
+		
 		for (i=0;i<interfaces->len;i++) {
 			hook = co_find_pair(interfaces->pdata[i], name);
 			if (hook)
@@ -1844,7 +1845,7 @@ int camel_object_state_write(void *vo)
 
 	savename = camel_file_util_savename(file);
 	dirname = g_path_get_dirname(savename);
-	camel_mkdir(dirname, 0777);
+	e_util_mkdir_hier(dirname, 0777);
 	g_free(dirname);
 	fp = g_fopen(savename, "wb");
 	if (fp != NULL) {
